<?php

namespace Drupal\scribit_pro\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\key\KeyRepositoryInterface;
use Drupal\scribit_pro\HelperService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ConfigForm.
 */
class ConfigForm extends ConfigFormBase {

  /**
   * Drupal\key\KeyRepositoryInterface definition.
   *
   * @var \Drupal\key\KeyRepositoryInterface
   */
  protected $keyRepository;

  /**
   * Scribit Pro helper.
   *
   * @var \Drupal\scribit_pro\HelperService
   */
  protected $helper;

  /**
   * Constructs a new ConfigForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\key\KeyRepositoryInterface $key_repository
   *   The key repository.
   * @param \Drupal\scribit_pro\HelperService $helper_service
   *   The Scribit Pro helper service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, KeyRepositoryInterface $key_repository, HelperService $helper_service) {
    parent::__construct($config_factory);

    $this->keyRepository = $key_repository;
    $this->helper = $helper_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('key.repository'),
      $container->get('scribit_pro.helper')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['scribit_pro.config'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('scribit_pro.config');

    if ($input = $form_state->getUserInput()) {
      $api_token = isset($input['api_token']) ? $input['api_token'] : $config->get('api_token');
      $scribit_id = isset($input['scribit_id']) ? $input['scribit_id'] : $config->get('scribit_id');
    }
    else {
      $api_token = $config->get('api_token');
      $scribit_id = $config->get('scribit_id');
    }

    $form['scribit_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Scribit ID'),
      '#description' => $this->t('The Scribit ID, can be found in your Scribit.pro account settings.'),
      '#weight' => '0',
      '#default_value' => $scribit_id ?? NULL,
      '#required' => TRUE,
    ];

    $form['api_token'] = [
      '#type' => 'key_select',
      '#title' => $this->t('Api Token'),
      '#description' => $this->t('The Api Token, can be generated in your Scribit.pro account settings.'),
      '#weight' => '2',
      '#default_value' => $api_token ?? NULL,
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#weight' => '2',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $values = $form_state->getValues();

    $this->config('scribit_pro.config')
      ->set('api_token', $values['api_token'])
      ->set('scribit_id', $values['scribit_id'])
      ->save();
  }

}
